# defi-services-lib
Query EVM State and Calculate The APY/APR, Wallet Information,... in Decentralized Applications
## Examples
Lending Protocol: [examples/lending_pools](https://github.com/phamvietbang/defi-services-lib/tree/main/examples/lending_pools/bsc)
